var util = require('util');
util._extend(util, require('core-util-is'));

var MPX = require('./core');

/**
 * Class holding configuration options
 */
function Config(options) {
  if(util.isUndefined(options)) options = {};
  
  /**
   * Updates configuration with passed values
   *
   * @return [MPX.Config] current configuration
   */
  this.update = function(config) {
    for(var key in this.keys) {
      var value = this[key];
      if(config.hasOwnProperty(key)) value = config[key];
      
      this.set(key, value);
    }
    
    return this;
  };
  
  /**
   * All of the configuration keys with their default values
   *
   * @constant
   * @api private
   */
  this.keys = {
    accessKey: null,
    secretKey: null,
    endpoint: null,
    version: null
  };
  
  /**
   * Sets property on the configuration object
   *
   * @api private
   */
  this.set = function(property, value, defaultValue) {
    if(value === undefined) {
      if(defaultValue === undefined) {
        defaultValue = this.keys[property];
      }
      this[property] = defaultValue;
    } else {
      this[property] = value;
    }
  };

  this.update(options);
}

MPX.Config = Config;
