var should = require('chai').should(),
    expect = require('chai').expect,
    helpers = require('./helpers'),
    MPX = helpers.MPX;

describe('MPX.Config', function() {
  var config;
  
  beforeEach(function() {
    config = new MPX.Config();
  });
  
  describe('update()', function() {
    it('preinitializes configuration', function() {
      for(var key in config.keys) {
        expect(config).to.have.property(key);
      }
    });
    
    it('updates configuration with given values', function() {
      config.update({ accessKey: 'my-key' });
      config.accessKey.should.eq('my-key');
    });
    
    it('does not change a property that is not listed among keys', function() {
      config.update({ whatever: 'my-key' });
      expect(config.whatever).to.eq(undefined);
    });
  });
  
  describe('set()', function() {
    it('sets to value to property of config object', function() {
      config.set('accessKey', 'my-key');
      config.accessKey.should.eq('my-key');
    });
    
    it('sets given defaultValue if given when no value is specified', function() {
      config.set('endpoint', undefined, 'defaultEndpoint');
      config.endpoint.should.eq('defaultEndpoint');
    });
    
    context('when both value and defaultValue are undefined', function() {
      it('takes assigns property a value from config.keys object', function() {
        config.keys.endpoint = 'mpx.mediapeers.com';
        config.set('endpoint');
        
        config.endpoint.should.eq('mpx.mediapeers.com');
      });
    });
  });
});
